/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface VectorSearchEndpointConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint#effective_budget_policy_id VectorSearchEndpoint#effective_budget_policy_id}
    */
    readonly effectiveBudgetPolicyId?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint#endpoint_type VectorSearchEndpoint#endpoint_type}
    */
    readonly endpointType: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint#id VectorSearchEndpoint#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint#name VectorSearchEndpoint#name}
    */
    readonly name: string;
    /**
    * custom_tags block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint#custom_tags VectorSearchEndpoint#custom_tags}
    */
    readonly customTags?: VectorSearchEndpointCustomTags[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint#timeouts VectorSearchEndpoint#timeouts}
    */
    readonly timeouts?: VectorSearchEndpointTimeouts;
}
export interface VectorSearchEndpointEndpointStatus {
}
export declare function vectorSearchEndpointEndpointStatusToTerraform(struct?: VectorSearchEndpointEndpointStatus): any;
export declare function vectorSearchEndpointEndpointStatusToHclTerraform(struct?: VectorSearchEndpointEndpointStatus): any;
export declare class VectorSearchEndpointEndpointStatusOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VectorSearchEndpointEndpointStatus | undefined;
    set internalValue(value: VectorSearchEndpointEndpointStatus | undefined);
    get message(): string;
    get state(): string;
}
export declare class VectorSearchEndpointEndpointStatusList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VectorSearchEndpointEndpointStatusOutputReference;
}
export interface VectorSearchEndpointCustomTags {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint#key VectorSearchEndpoint#key}
    */
    readonly key: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint#value VectorSearchEndpoint#value}
    */
    readonly value?: string;
}
export declare function vectorSearchEndpointCustomTagsToTerraform(struct?: VectorSearchEndpointCustomTags | cdktf.IResolvable): any;
export declare function vectorSearchEndpointCustomTagsToHclTerraform(struct?: VectorSearchEndpointCustomTags | cdktf.IResolvable): any;
export declare class VectorSearchEndpointCustomTagsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): VectorSearchEndpointCustomTags | cdktf.IResolvable | undefined;
    set internalValue(value: VectorSearchEndpointCustomTags | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class VectorSearchEndpointCustomTagsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: VectorSearchEndpointCustomTags[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): VectorSearchEndpointCustomTagsOutputReference;
}
export interface VectorSearchEndpointTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint#create VectorSearchEndpoint#create}
    */
    readonly create?: string;
}
export declare function vectorSearchEndpointTimeoutsToTerraform(struct?: VectorSearchEndpointTimeouts | cdktf.IResolvable): any;
export declare function vectorSearchEndpointTimeoutsToHclTerraform(struct?: VectorSearchEndpointTimeouts | cdktf.IResolvable): any;
export declare class VectorSearchEndpointTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): VectorSearchEndpointTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: VectorSearchEndpointTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint databricks_vector_search_endpoint}
*/
export declare class VectorSearchEndpoint extends cdktf.TerraformResource {
    static readonly tfResourceType = "databricks_vector_search_endpoint";
    /**
    * Generates CDKTF code for importing a VectorSearchEndpoint resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the VectorSearchEndpoint to import
    * @param importFromId The id of the existing VectorSearchEndpoint that should be imported. Refer to the {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the VectorSearchEndpoint to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/databricks/databricks/1.79.0/docs/resources/vector_search_endpoint databricks_vector_search_endpoint} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options VectorSearchEndpointConfig
    */
    constructor(scope: Construct, id: string, config: VectorSearchEndpointConfig);
    get creationTimestamp(): number;
    get creator(): string;
    private _effectiveBudgetPolicyId?;
    get effectiveBudgetPolicyId(): string;
    set effectiveBudgetPolicyId(value: string);
    resetEffectiveBudgetPolicyId(): void;
    get effectiveBudgetPolicyIdInput(): string | undefined;
    get endpointId(): string;
    private _endpointStatus;
    get endpointStatus(): VectorSearchEndpointEndpointStatusList;
    private _endpointType?;
    get endpointType(): string;
    set endpointType(value: string);
    get endpointTypeInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get lastUpdatedTimestamp(): number;
    get lastUpdatedUser(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get numIndexes(): number;
    private _customTags;
    get customTags(): VectorSearchEndpointCustomTagsList;
    putCustomTags(value: VectorSearchEndpointCustomTags[] | cdktf.IResolvable): void;
    resetCustomTags(): void;
    get customTagsInput(): cdktf.IResolvable | VectorSearchEndpointCustomTags[] | undefined;
    private _timeouts;
    get timeouts(): VectorSearchEndpointTimeoutsOutputReference;
    putTimeouts(value: VectorSearchEndpointTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | VectorSearchEndpointTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
